<?php

namespace Drupal\mcapi_forms\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\mcapi\Entity\Workflow;

/**
 * Defines the designed form entity class.
 *
 * @ConfigEntityType(
 *   id = "mc_form",
 *   label = @Translation("Transaction form"),
 *   config_prefix = "form",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "status" = "status"
 *   },
 *   handlers = {
 *     "list_builder" = "Drupal\mcapi_forms\Entity\McFormListBuilder",
 *     "form" = {
 *       "edit" = "Drupal\mcapi_forms\FormEditorForm",
 *       "add" = "Drupal\mcapi_forms\FormEditorForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm",
 *       "status" = "Drupal\mcapi_forms\ConfirmMcFormForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\mcapi_forms\Entity\McFormRouteProvider",
 *     },
 *   },
 *   links = {
 *     "add-form" = "/admin/accounting/form/create",
 *     "edit-form" = "/admin/accounting/form/{mc_form}/edit",
 *     "delete-form" = "/admin/accounting/form/{mc_form}/delete",
 *     "status-form" = "/admin/accounting/form/{mc_form}/status",
 *     "collection" = "/admin/accounting/form"
 *   },
 *   admin_permission = "configure mcapi",
 *   config_export = {
 *     "id",
 *     "status",
 *     "label",
 *     "wallet_link_title",
 *     "workflow_type",
 *     "path",
 *     "twig",
 *     "menu",
 *     "quicklink",
 *     "presets",
 *   }
 * )
 */
class McForm extends ConfigEntityBase {

  /**
   * Unique ID
   * @var string
   */
  public $id;

  /**
   * Name to show in lists
   * @var string
   */
  public $label;

  /**
   * Short description
   * @var string
   */
  public $wallet_link_title;

  /**
   * Whether this workflow is allowed to be used
   * @var string
   */
  public $workflow_type;

  /**
   * Whether this is BILL or CREDIT or THIRDPARTY
   * @var string
   */
  public $path;

  /**
   * Structured data
   * @var string
   */
  public $twig;

  /**
   * Structured data
   * @var array
   */
  public $presets;

  /**
   * The menu link title, parent menu, and weight
   * @var array
   */
  public $menu;

  /**
   * TRUE to show a link to this form in the wallet extrafields quicklinks.
   * @var bool
   */
  protected $quicklink;

  function getWalletLinkTitle() : string {
    return (string) $this->wallet_link_title;
  }

  function getWorkflowId() : string {
    return (string) $this->workflow_type;
  }

  function setWorkflowId($workflow_id) : static {
    $this->workflow_type = $workflow_id;
    return $this;
  }

  function getWorkflow() : Workflow|NULL {
    return Workflow::load($this->workflow_type);
  }

  function getPath() : string {
    return (string) $this->path;
  }

  function getMenuItem() : \stdClass {
    return (object) $this->menu;
  }

  function getPreset($field_name) {
    return $this->presets[$field_name] ?? '';
  }

  function hasTransactionTab() : bool {
    return $this->menu ? !empty($this->menu['add_transaction_tab']) : FALSE;
  }

  function getTwigTemplate() : string {
    return (string) $this->twig;
  }

  function setTwigTemplate(string $twig) : static {
    $this->twig = $twig;
    return $this;
  }

 function getQuicklink() : bool {
   return (bool)$this->quicklink;
 }

}
