<?php

namespace Drupal\mcapi_forms\Entity;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Url;
use Drupal\Core\Link;

/**
 * Defines a class to build a listing of MCForm entities.
 */
class McFormListBuilder extends EntityListBuilder {

  /**
   * {@inheritDoc}
   */
  public function buildHeader() {
    $header = [
      'title' => $this->t('Form name'),
      'path' => $this->t('Path'),
      'workflow' => [
        'data' => $this->t('Type/Workflow'),
        'class' => [RESPONSIVE_PRIORITY_LOW],
      ],
      'operations' => $this->t('Operations'),
    ];
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritDoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row['id']['data'] = [
      '#type' => 'markup',
      '#markup' => $entity->label(),
    ];

    $row['path']['data'] = [
      '#type' => 'link',
      '#title' => $entity->getPath(),
      '#url' => Url::fromUserInput($entity->getPath())
    ];
    $row['workflow']['data'] = [
      '#markup' => $entity->getWorkflowId()
    ];

    if (!$entity->status()) {
      $row['id']['style'] = 'color:gray';
      $row['workflow']['style'] = 'color:gray';
    }
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   *
   * Builds the entity listing as renderable array for table.html.twig.
   *
   * @todo Add a link to add a new item to the #empty text.
   */
  public function render() {
    $build = parent::render();
    foreach ($this->moduleHandler()->invokeAll('mcapi_form_list') as $form_name => $info) {
      $url = Url::fromRoute($info['route_name'], $info['route_parameters']??[]);
      $build['table']['#rows'][$form_name] = [
        'title' => $info['label'],
        'path' => Link::fromTextAndUrl($url->toString(), $url),
        'workflow' => $info['workflow'],
        'operations' => []
      ];
    }
    return $build;
  }

  /**
   * {@inheritDoc}
   */
  protected function getDefaultOperations(EntityInterface $entity) {
    return parent::getDefaultOperations($entity) + [
      'status' => [
        'title' => $entity->status() ? $this->t('Disable') : $this->t('Enable'),
        'weight' => 20,
        'url' => $this->ensureDestination($entity->toUrl('status-form')),
      ]
    ];
  }

}
