<?php

namespace Drupal\mcapi_forms\Entity;

use Drupal\Core\Entity\Routing\DefaultHtmlRouteProvider;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Config\Config;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides routes for the wallet entity.
 */
class McFormRouteProvider extends DefaultHtmlRouteProvider {

  protected $config;

  /**
   * Constructs a new DefaultHtmlRouteProvider.
   */
  public function __construct($entity_type_manager, $entity_field_manager, Config $config) {
    parent::__construct($entity_type_manager, $entity_field_manager);
    $this->config = $config;
  }

  /**
   * {@inheritDoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('entity_field.manager'),
      $container->get('config.factory')->get('mcapi.settings')
    );
  }

  /**
   * {@inheritDoc}
   */
  public function getRoutes(EntityTypeInterface $entity_type) {
    $collection = parent::getRoutes($entity_type);
    // Remove the mcapi route for viewing forms, coz it clashes
    $route = new \Symfony\Component\Routing\Route('/admin/accounting/form/{mc_form}/status');
    $route->addDefaults([
      '_entity_form' => 'mc_form.status',
    ]);
    $route->addRequirements([
      '_permission' => 'configure mcapi',
    ]);
    $route->addOptions(['_admin_route' => TRUE]);
    $collection->add("entity.mc_form.status_form", $route);
    return $collection;
  }

}

