<?php

namespace Drupal\mcapi\Element;

use Drupal\Core\Render\Element\RenderElementBase;

/**
 * Provides an element showing a wallet's balance over time.
 *
 * @FormElement("mcapi_balance_history")
 */
class BalanceHistory extends RenderElementBase {

  /**
   * {@inheritDoc}
   */
  public function getInfo() {

    $class = static::class;
    return [
      '#width' => 400,
      '#height' => 133,
      '#format_curr' => TRUE,
      '#pre_render' => [[$class, 'preRender']]
    ];
  }

  public static function preRender(array $element): array {
    $element['#theme'] = 'mc_timeline';
    $points = \Drupal::entityTypeManager()
      ->getStorage('mc_transaction')
      ->historyOfWallet($element['#wallet']->id());
    $points[\Drupal::time()->getRequestTime()] = end($points);
    // Apply smoothing, or even roughing.
    if (count($points) < $element['#width'] / 3) {
      // Step method, for a small number of points.
      $times = $values = [];
      // Make two values for each one in the keys and values.
      foreach ($points as $time => $bal) {
        $times[] = $time;
        $times[] = $time + 1;
        $bal_float = $bal;
        $values[] = $bal_float;
        $values[] = $bal_float;
      }
      // Now slide the arrays against each other to create steps.
      array_pop($values);
      array_shift($times);
      $element['#points'] = array_combine($times, $values);
    }
    elseif (count($points) > $element['#width']) {
      // Decimate the array, for a large number of points.
      $ratio = count($points) / $element['#width'];
      $factor = intval($ratio + 1);
      // Now iterate through the array taking 1 out of every $factor values.
      $i = 0;
      foreach ($points as $key => &$value) {
        if ($i % $factor != 0) {
          unset($points[$key]);
        }
        else {
          $value = $value;
        }
        $i++;
      }
      $element['#points'] = $points;
    }
    return $element;
  }

}
