<?php

namespace Drupal\mcapi\Plugin\Field\FieldWidget;

use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\FieldItemInterface;
use Drupal\mcapi\Entity\Wallet;

/**
 * Plugin implementation of the wallet selector widget.
 *
 * @FieldWidget(
 *   id = "mc_entry",
 *   label = @Translation("Entry"),
 *   description = @Translation("Enter the payer, payee, quant and description"),
 *   field_types = {
 *     "entry"
 *   },
 *   multiple_values = true
 * )
 */
class EntryWidget extends WidgetBase {

  /**
   * {@inheritDoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $raw = static::rawElements($items[$delta], $items->getEntity()->workflow->entity->direction);
    $w = 0;
    foreach ($raw as &$e) {
      $e['#weight'] = $w++;
    }
    return $element+= $raw;
  }

  /**
   * Provide form elements without any field API clutter.
   *
   * @param FieldItemInterface $item
   * @param string $direction
   *   bill, credit or 3rdparty
   * @return type
   */
  static function rawElements(FieldItemInterface $item, $direction) {
    return [
      'description' => [
        '#title' => t('Description'),
        '#type' => 'textfield',
        '#default_value' => $item->description??'',
        '#weight' => 2
      ],
      'quant' => [
        '#title' => t('Amount'),
        '#type' => 'worth',
        '#default_value' => $item->quant??'',
        '#weight' => 4
      ],
      'payee_wid' => [
        '#title' => t('Payee'),
        '#type' => $direction == 'bill' ? 'my_wallet' : 'wallet_entity_auto',
        '#default_value' => $item->payee_wid ? Wallet::load($item->payee_wid) :  '',
        '#placeholder' => t('Wallet name'),
        '#required' => $direction == 'bill',
        '#weight' => 6
      ],
      'payer_wid' => [
        '#title' => t('Payer'),
        '#type' => $direction == 'credit' ? 'my_wallet' : 'wallet_entity_auto',
        '#default_value' => $item->payer_wid ? Wallet::load($item->payer_wid) : '',
        '#placeholder' => t('Wallet name'),
        '#weight' => 8,
        '#required' => $direction == 'credit',
      ]
    ];
  }

  /**
   * {@inheritDoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    $values['primary'] = 1;
    if (!isset($values['metadata'])) {
      $values['metadata'] = [];
    }
    return $values;
  }

}
